<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>AccountItem</name>
    <message>
        <source>Sync successful</source>
        <translation type="vanished">Conexão bem-sucedida</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation type="vanished">Erro de rede</translation>
    </message>
    <message>
        <source>Server exception</source>
        <translation type="vanished">Exceção do servidor</translation>
    </message>
    <message>
        <source>Storage full</source>
        <translation type="vanished">Armazenamento cheio</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>Local account</source>
        <translation type="vanished">Conta local</translation>
    </message>
    <message>
        <source>Event types</source>
        <translation type="vanished">Tipos de eventos</translation>
    </message>
</context>
<context>
    <name>CColorPickerWidget</name>
    <message>
        <source>Color</source>
        <translation type="vanished">Cor</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Salvar</translation>
    </message>
</context>
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation type="vanished">Segunda-feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="vanished">Terça-feira</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="vanished">Quarta-feira</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="vanished">Quinta-feira</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="vanished">Sexta-feira</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="vanished">Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="vanished">Domingo</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">A</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">D</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="vanished">Lunar</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation type="vanished">Novo Evento</translation>
    </message>
</context>
<context>
    <name>CMonthScheduleNumItem</name>
    <message>
        <source>%1 more</source>
        <translation type="vanished">%1 mais</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation type="vanished">Novo evento</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation type="vanished">Novo Evento</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">A</translation>
    </message>
</context>
<context>
    <name>CMyScheduleView</name>
    <message>
        <source>My Event</source>
        <translation type="vanished">Evento</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">Ok</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Excluir</translation>
    </message>
    <message>
        <source>Edit</source>
        <comment>button</comment>
        <translation type="vanished">Editar</translation>
    </message>
</context>
<context>
    <name>CPushButton</name>
    <message>
        <source>New event type</source>
        <translation type="vanished">Novo tipo de evento</translation>
    </message>
</context>
<context>
    <name>CScheduleDlg</name>
    <message>
        <source>New Event</source>
        <translation type="vanished">Novo Evento</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation type="vanished">Editar Evento</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation type="vanished">O tempo de término deve ser maior que o tempo de início</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">Ok</translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="vanished">Nunca</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation type="vanished">No momento do evento</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation type="vanished">15 minutos antes</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation type="vanished">30 minutos antes</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation type="vanished">1 hora antes</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation type="vanished">1 dia antes</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation type="vanished">2 dias antes</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation type="vanished">1 semana antes</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation type="vanished">No dia de início (9:00 AM)</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation type="vanished">vez(es)</translation>
    </message>
    <message>
        <source>Enter a name please</source>
        <translation type="vanished">Insira um nome</translation>
    </message>
    <message>
        <source>The name can not only contain whitespaces</source>
        <translation type="vanished">O nome não pode conter apenas espaços em branco</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="vanished">Tipo:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Descrição:</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation type="vanished">Dia Inteiro:</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation type="vanished">Inicia em:</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation type="vanished">Termina em:</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation type="vanished">Lembre-me:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation type="vanished">Repetir:</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation type="vanished">Termina em:</translation>
    </message>
    <message>
        <source>Calendar account:</source>
        <translation type="vanished">Conta de calendário:</translation>
    </message>
    <message>
        <source>Calendar account</source>
        <translation type="vanished">Conta de calendário</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Tipo</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="vanished">Descrição</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation type="vanished">Dia Inteiro</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation type="vanished">Horário:</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="vanished">Horário</translation>
    </message>
    <message>
        <source>Solar</source>
        <translation type="vanished">Solar</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="vanished">Lunar</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation type="vanished">Inicia em</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation type="vanished">Termina em</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation type="vanished">Lembre-me</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation type="vanished">Repetir</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation type="vanished">Diariamente</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation type="vanished">Dias úteis</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation type="vanished">Semanalmente</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation type="vanished">Mensalmente</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation type="vanished">Anualmente</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation type="vanished">Termina em</translation>
    </message>
    <message>
        <source>After</source>
        <translation type="vanished">Depois</translation>
    </message>
    <message>
        <source>On</source>
        <translation type="vanished">Ativo</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Salvar</translation>
    </message>
</context>
<context>
    <name>CScheduleOperation</name>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation type="vanished">Todas as ocorrências de um evento repetitivo devem ter o mesmo status durante o dia inteiro.</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation type="vanished">Alterar todas as ocorrências?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation type="vanished">Alterar Tudo</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation type="vanished">A regra de repetição deste evento será alterada.</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation type="vanished">Um evento será excluído.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation type="vanished">Excluir este evento?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Excluir</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation type="vanished">Excluir todas as ocorrências deste evento; ou apenas a ocorrência selecionada?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation type="vanished">Excluir Tudo</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation type="vanished">Excluir Apenas Este Evento</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation type="vanished">Excluir este evento e todas as suas ocorrências futuras; ou apenas a ocorrência selecionada?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation type="vanished">Excluir Todos os Eventos Futuros</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation type="vanished">Um evento repetido será alterado.</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation type="vanished">Alterar apenas esta ocorrência do evento; ou todas as ocorrências?</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="vanished">Tudo</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation type="vanished">Apenas Este Evento</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation type="vanished">Alterar apenas esta ocorrência do evento; ou esta e todas as ocorrências futuras?</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation type="vanished">Todos os Eventos Futuros</translation>
    </message>
    <message>
        <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
        <translation type="vanished">Você selecionou um mês bissexto e será lembrado de acordo com as regras do calendário lunar.</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">Ok</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation type="vanished">A</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">D</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Excluir</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation type="vanished">Dia Inteiro</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation type="vanished">Nenhum resultado encontrado</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation type="vanished">DIA INTEIRO</translation>
    </message>
</context>
<context>
    <name>CSettingDialog</name>
    <message>
        <source>Manual</source>
        <translation type="vanished">Manual</translation>
    </message>
    <message>
        <source>15 mins</source>
        <translation type="vanished">15 mins</translation>
    </message>
    <message>
        <source>30 mins</source>
        <translation type="vanished">30 mins</translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation type="vanished">1 hora</translation>
    </message>
    <message>
        <source>24 hours</source>
        <translation type="vanished">24 horas</translation>
    </message>
    <message>
        <source>Sync Now</source>
        <translation type="vanished">Sincronizar Agora</translation>
    </message>
    <message>
        <source>Last sync</source>
        <translation type="vanished">Última sincronização</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="vanished">Segunda-feira</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="vanished">Domingo</translation>
    </message>
    <message>
        <source>12-hour clock</source>
        <translation type="vanished">Formato de 12 horas</translation>
    </message>
    <message>
        <source>24-hour clock</source>
        <translation type="vanished">Formato de 24 horas</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CTimeEdit</name>
    <message>
        <source>(%1 mins)</source>
        <translation type="vanished">(%1 minutos)</translation>
    </message>
    <message>
        <source>(%1 hour)</source>
        <translation type="vanished">(%1 hora)</translation>
    </message>
    <message>
        <source>(%1 hours)</source>
        <translation type="vanished">(%1 horas)</translation>
    </message>
</context>
<context>
    <name>CTitleWidget</name>
    <message>
        <source>Y</source>
        <translation type="vanished">A</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
    <message>
        <source>W</source>
        <translation type="vanished">S</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">D</translation>
    </message>
    <message>
        <source>Search events and festivals</source>
        <translation type="vanished">Procurar eventos e datas comemorativas</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation type="vanished">Dom</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation type="vanished">Seg</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation type="vanished">Ter</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation type="vanished">Qua</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation type="vanished">Qui</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation type="vanished">Sex</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation type="vanished">Sáb</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation type="vanished">Semana</translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="vanished">A</translation>
    </message>
</context>
<context>
    <name>CYearScheduleView</name>
    <message>
        <source>All Day</source>
        <translation type="vanished">Dia Inteiro</translation>
    </message>
    <message>
        <source>No event</source>
        <translation type="vanished">Nenhum evento</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">A</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation type="vanished">Calendário</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation type="vanished">O Calendário é uma ferramenta que permite agendar e visualizar eventos.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation type="vanished">Calendário</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="vanished">Gerenciar</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation type="vanished">Política de privacidade</translation>
    </message>
    <message>
        <source>Syncing...</source>
        <translation type="vanished">Sincronizando...</translation>
    </message>
    <message>
        <source>Sync successful</source>
        <translation type="vanished">Sincronização bem-sucedida</translation>
    </message>
    <message>
        <source>Sync failed, please try later</source>
        <translation type="vanished">A sincronização falhou, tente novamente mais tarde</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation type="vanished">Dia Inteiro</translation>
    </message>
</context>
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Trabalho</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Social</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outro</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Um dia antes do início</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Lembre-me amanhã</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Lembre-me mais tarde</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minutos depois</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 hora depois</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 horas depois</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Amanhã</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Agendar Lembrete</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 às %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Excluir</translation>
    </message>
    <message>
        <source>New event</source>
        <translation type="vanished">Novo evento</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation type="vanished">Novo Evento</translation>
    </message>
</context>
<context>
    <name>JobTypeListView</name>
    <message>
        <source>You are deleting an event type.</source>
        <translation type="vanished">Você está a eliminar um tipo de evento.</translation>
    </message>
    <message>
        <source>All events under this type will be deleted and cannot be recovered.</source>
        <translation type="vanished">Todos os eventos deste tipo serão eliminados e não poderão ser recuperados.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Cancelar.</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Excluir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Account settings</source>
        <translation type="vanished">Configurações de conta</translation>
    </message>
    <message>
        <source>Account</source>
        <translation type="vanished">Conta</translation>
    </message>
    <message>
        <source>Select items to be synced</source>
        <translation type="vanished">Selecionar itens para sincronizar</translation>
    </message>
    <message>
        <source>Events</source>
        <translation type="vanished">Eventos</translation>
    </message>
    <message>
        <source>General settings</source>
        <translation type="vanished">Definições gerais</translation>
    </message>
    <message>
        <source>Sync interval</source>
        <translation type="vanished">Intervalo de sincronização</translation>
    </message>
    <message>
        <source>Manage calendar</source>
        <translation type="vanished">Gerenciar calendário</translation>
    </message>
    <message>
        <source>Calendar account</source>
        <translation type="vanished">Conta de calendário</translation>
    </message>
    <message>
        <source>Event types</source>
        <translation type="vanished">Tipos de eventos</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Geral</translation>
    </message>
    <message>
        <source>First day of week</source>
        <translation type="vanished">Primeiro dia da semana</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="vanished">Horário</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="vanished">Hoje</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="vanished">Hoje</translation>
    </message>
</context>
<context>
    <name>ScheduleTypeEditDlg</name>
    <message>
        <source>New event type</source>
        <translation type="vanished">Novo tipo de evento</translation>
    </message>
    <message>
        <source>Edit event type</source>
        <translation type="vanished">Editar o tipo de evento</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">Nome:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="vanished">Cor:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Salvar</translation>
    </message>
    <message>
        <source>The name can not only contain whitespaces</source>
        <translation type="vanished">O nome não pode ser apenas espaços em branco</translation>
    </message>
    <message>
        <source>Enter a name please</source>
        <translation type="vanished">Insira um nome</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation type="vanished">Ajuda</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation type="vanished">Excluir evento</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Copiar</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="vanished">Recortar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="vanished">Colar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Excluir</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation type="vanished">Selecionar Tudo</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Y</source>
        <translation type="vanished">A</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
</context>
<context>
    <name>TimeJumpDialog</name>
    <message>
        <source>Go</source>
        <comment>button</comment>
        <translation type="vanished">Ir</translation>
    </message>
</context>
<context>
    <name>UserloginWidget</name>
    <message>
        <source>Sign In</source>
        <comment>button</comment>
        <translation type="vanished">Entrar</translation>
    </message>
    <message>
        <source>Sign Out</source>
        <comment>button</comment>
        <translation type="vanished">Sair</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation type="vanished">A</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="vanished">Hoje</translation>
    </message>
</context>
</TS>